OpenPath

Struct OpenPath 

pub struct OpenPath(/* private fields */);
Future produced by crate::Connection::open_path

Implementations

Source

impl OpenPath

pub fn path_id(&self) -> Option<PathId>

Returns the path ID of the new path being opened.

If an error occurred before a path ID was allocated, None is returned. In this case the future is ready and polling it will immediately yield the error.

The returned value remains the same for the entire lifetime of this future.